`spyRMSD` documentation
=======================

`spyRMSD` is a Python tool for symmetry-corrected RMSD calculations.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
